@@ -1,6 +1,6 @@
 import ibis
 
-from pandasdb.sql.connection.connection import Connection
+from pandasdb.io.connection.connection import Connection
 
 
 class PandasConnection(Connection):
